#[non_exhaustive]pub struct CreateEnvironmentConnectorInput {
pub client_token: Option<String>,
pub environment_id: Option<String>,
pub type: Option<ConnectorType>,
pub appliance_fqdn: Option<String>,
pub secret_identifier: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_token: Option<String>This parameter is not used in Amazon EVS currently. If you supply input for this parameter, it will have no effect.
A unique, case-sensitive identifier that you provide to ensure the idempotency of the connector creation request. If you do not specify a client token, a randomly generated token is used for the request to ensure idempotency.
environment_id: Option<String>A unique ID for the environment to create the connector in.
type: Option<ConnectorType>The type of connector to create.
-
OPERATIONS_MANAGER: Connector to an Operations Manager appliance. Required for VCF 9x environments. -
SDDC_MANAGER: Connector to an SDDC Manager appliance. Required for VCF 5.x environments. -
VCENTER: Connector to a vCenter Server appliance. Required for features that depend on vCenter, such as Windows Server license-included.
appliance_fqdn: Option<String>The fully qualified domain name (FQDN) of the VCF appliance that the connector targets.
secret_identifier: Option<String>The ARN or name of the Amazon Web Services Secrets Manager secret that stores the credentials for the VCF appliance. SDDC_MANAGER requires an apiKey field; OPERATIONS_MANAGER and VCENTER require username and password fields.
Do not use credentials with Administrator privileges. We recommend using a service account with read-only permissions.
Implementations
Sourceimpl CreateEnvironmentConnectorInput
impl CreateEnvironmentConnectorInput
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
This parameter is not used in Amazon EVS currently. If you supply input for this parameter, it will have no effect.
A unique, case-sensitive identifier that you provide to ensure the idempotency of the connector creation request. If you do not specify a client token, a randomly generated token is used for the request to ensure idempotency.
Sourcepub fn environment_id(&self) -> Option<&str>
pub fn environment_id(&self) -> Option<&str>
A unique ID for the environment to create the connector in.
Sourcepub fn type(&self) -> Option<&ConnectorType>
pub fn type(&self) -> Option<&ConnectorType>
The type of connector to create.
-
OPERATIONS_MANAGER: Connector to an Operations Manager appliance. Required for VCF 9x environments. -
SDDC_MANAGER: Connector to an SDDC Manager appliance. Required for VCF 5.x environments. -
VCENTER: Connector to a vCenter Server appliance. Required for features that depend on vCenter, such as Windows Server license-included.
Sourcepub fn appliance_fqdn(&self) -> Option<&str>
pub fn appliance_fqdn(&self) -> Option<&str>
The fully qualified domain name (FQDN) of the VCF appliance that the connector targets.
Sourcepub fn secret_identifier(&self) -> Option<&str>
pub fn secret_identifier(&self) -> Option<&str>
The ARN or name of the Amazon Web Services Secrets Manager secret that stores the credentials for the VCF appliance. SDDC_MANAGER requires an apiKey field; OPERATIONS_MANAGER and VCENTER require username and password fields.
Do not use credentials with Administrator privileges. We recommend using a service account with read-only permissions.
Sourceimpl CreateEnvironmentConnectorInput
impl CreateEnvironmentConnectorInput
Sourcepub fn builder() -> CreateEnvironmentConnectorInputBuilder
pub fn builder() -> CreateEnvironmentConnectorInputBuilder
Creates a new builder-style object to manufacture CreateEnvironmentConnectorInput.