#[non_exhaustive]pub struct Check {
pub type: Option<CheckType>,
pub id: Option<String>,
pub result: Option<CheckResult>,
pub impaired_since: Option<DateTime>,
}Expand description
A check on the environment to identify environment health and validate VMware VCF licensing compliance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: Option<CheckType>The check type. Amazon EVS performs the following checks:
-
KEY_REUSE: Verifies that the VCF license key is not used by another Amazon EVS environment. -
KEY_COVERAGE: Verifies that the VCF license key allocates sufficient vCPU cores for all deployed hosts. -
REACHABILITY: Verifies that the Amazon EVS control plane has a persistent connection to SDDC Manager. -
HOST_COUNT: Verifies that the environment meets the minimum host count. -
VCENTER_REACHABILITY: Verifies vCenter Server reachability through the vCenter connector. -
VCENTER_VM_SYNC: Verifies that the vCenter connector can synchronize VM inventory from vCenter Server. -
VCENTER_VM_EVENT: Verifies that the vCenter connector can receive VM lifecycle events from vCenter Server. -
OPERATIONS_MANAGER_REACHABILITY: Verifies Operations Manager reachability through the Operations Manager connector. -
SDDC_MANAGER_REACHABILITY: Verifies SDDC Manager reachability through the SDDC Manager connector. -
SDDC_MANAGER_HOST_COUNT: Verifies that the host count reported by SDDC Manager meets Amazon EVS minimum requirements. -
SDDC_MANAGER_KEY_COVERAGE: Verifies that the VCF license key configured in SDDC Manager covers all deployed hosts. -
SDDC_MANAGER_KEY_REUSE: Verifies that the VCF license key configured in SDDC Manager is not used by another Amazon EVS environment. -
CONNECTOR_HEALTH: Aggregate health across all connectors in the environment.
id: Option<String>A unique ID for the check.
result: Option<CheckResult>The check result.
impaired_since: Option<DateTime>The time when environment health began to be impaired.
Implementations
Sourceimpl Check
impl Check
Sourcepub fn type(&self) -> Option<&CheckType>
pub fn type(&self) -> Option<&CheckType>
The check type. Amazon EVS performs the following checks:
-
KEY_REUSE: Verifies that the VCF license key is not used by another Amazon EVS environment. -
KEY_COVERAGE: Verifies that the VCF license key allocates sufficient vCPU cores for all deployed hosts. -
REACHABILITY: Verifies that the Amazon EVS control plane has a persistent connection to SDDC Manager. -
HOST_COUNT: Verifies that the environment meets the minimum host count. -
VCENTER_REACHABILITY: Verifies vCenter Server reachability through the vCenter connector. -
VCENTER_VM_SYNC: Verifies that the vCenter connector can synchronize VM inventory from vCenter Server. -
VCENTER_VM_EVENT: Verifies that the vCenter connector can receive VM lifecycle events from vCenter Server. -
OPERATIONS_MANAGER_REACHABILITY: Verifies Operations Manager reachability through the Operations Manager connector. -
SDDC_MANAGER_REACHABILITY: Verifies SDDC Manager reachability through the SDDC Manager connector. -
SDDC_MANAGER_HOST_COUNT: Verifies that the host count reported by SDDC Manager meets Amazon EVS minimum requirements. -
SDDC_MANAGER_KEY_COVERAGE: Verifies that the VCF license key configured in SDDC Manager covers all deployed hosts. -
SDDC_MANAGER_KEY_REUSE: Verifies that the VCF license key configured in SDDC Manager is not used by another Amazon EVS environment. -
CONNECTOR_HEALTH: Aggregate health across all connectors in the environment.
Sourcepub fn result(&self) -> Option<&CheckResult>
pub fn result(&self) -> Option<&CheckResult>
The check result.
Sourcepub fn impaired_since(&self) -> Option<&DateTime>
pub fn impaired_since(&self) -> Option<&DateTime>
The time when environment health began to be impaired.