#[non_exhaustive]pub struct ConnectorCheck {
pub type: Option<CheckType>,
pub result: Option<CheckResult>,
pub last_check_attempt: Option<DateTime>,
pub impaired_since: Option<DateTime>,
}Expand description
A check on a connector to identify connectivity health.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: Option<CheckType>The check type.
result: Option<CheckResult>The check result.
last_check_attempt: Option<DateTime>The date and time of the last check attempt.
impaired_since: Option<DateTime>The time when connector health began to be impaired.
Implementations
Sourceimpl ConnectorCheck
impl ConnectorCheck
Sourcepub fn result(&self) -> Option<&CheckResult>
pub fn result(&self) -> Option<&CheckResult>
The check result.
Sourcepub fn last_check_attempt(&self) -> Option<&DateTime>
pub fn last_check_attempt(&self) -> Option<&DateTime>
The date and time of the last check attempt.
Sourcepub fn impaired_since(&self) -> Option<&DateTime>
pub fn impaired_since(&self) -> Option<&DateTime>
The time when connector health began to be impaired.
Sourceimpl ConnectorCheck
impl ConnectorCheck
Sourcepub fn builder() -> ConnectorCheckBuilder
pub fn builder() -> ConnectorCheckBuilder
Creates a new builder-style object to manufacture ConnectorCheck.