#[non_exhaustive]pub struct Connector {
pub environment_id: Option<String>,
pub connector_id: Option<String>,
pub type: Option<ConnectorType>,
pub appliance_fqdn: Option<String>,
pub secret_arn: Option<String>,
pub state: Option<ConnectorState>,
pub state_details: Option<String>,
pub status: Option<CheckResult>,
pub checks: Option<Vec<ConnectorCheck>>,
pub created_at: Option<DateTime>,
pub modified_at: Option<DateTime>,
}Expand description
An object that represents a connector for an Amazon EVS environment. A connector establishes a vCenter connection using the credentials stored in Amazon Web Services Secrets Manager.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.environment_id: Option<String>The unique ID of the environment that the connector belongs to.
connector_id: Option<String>The unique ID of the connector.
type: Option<ConnectorType>The type of the connector.
appliance_fqdn: Option<String>The fully qualified domain name (FQDN) of the VCF appliance that the connector connects to.
secret_arn: Option<String>The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that stores the credentials for the VCF appliance.
state: Option<ConnectorState>The state of the connector.
state_details: Option<String>A detailed description of the connector state.
status: Option<CheckResult>The status of the connector.
checks: Option<Vec<ConnectorCheck>>A list of checks that are run on the connector.
created_at: Option<DateTime>The date and time that the connector was created.
modified_at: Option<DateTime>The date and time that the connector was modified.
Implementations
Sourceimpl Connector
impl Connector
Sourcepub fn environment_id(&self) -> Option<&str>
pub fn environment_id(&self) -> Option<&str>
The unique ID of the environment that the connector belongs to.
Sourcepub fn connector_id(&self) -> Option<&str>
pub fn connector_id(&self) -> Option<&str>
The unique ID of the connector.
Sourcepub fn type(&self) -> Option<&ConnectorType>
pub fn type(&self) -> Option<&ConnectorType>
The type of the connector.
Sourcepub fn appliance_fqdn(&self) -> Option<&str>
pub fn appliance_fqdn(&self) -> Option<&str>
The fully qualified domain name (FQDN) of the VCF appliance that the connector connects to.
Sourcepub fn secret_arn(&self) -> Option<&str>
pub fn secret_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that stores the credentials for the VCF appliance.
Sourcepub fn state(&self) -> Option<&ConnectorState>
pub fn state(&self) -> Option<&ConnectorState>
The state of the connector.
Sourcepub fn state_details(&self) -> Option<&str>
pub fn state_details(&self) -> Option<&str>
A detailed description of the connector state.
Sourcepub fn status(&self) -> Option<&CheckResult>
pub fn status(&self) -> Option<&CheckResult>
The status of the connector.
Sourcepub fn checks(&self) -> &[ConnectorCheck]
pub fn checks(&self) -> &[ConnectorCheck]
A list of checks that are run on the connector.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .checks.is_none().
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The date and time that the connector was created.
Sourcepub fn modified_at(&self) -> Option<&DateTime>
pub fn modified_at(&self) -> Option<&DateTime>
The date and time that the connector was modified.